#!/bin/bash

pwd=$(pwd)

export PS1='\w\$ '
umask 022

version="07"

export PATH=$pwd/bin:$PATH

export LD_LIBRARY_PATH=$pwd/lib:$LD_LIBRARY_PATH


if [ ! -e home ]
then
 echo "--------------------------------------------------------------"
 echo "mkdir home"
 mkdir home
fi

if [ -e home/.version ];then
 lastrun=`cat home/.version`
else
 lastrun="00"
fi

#check Java
if [ ! -e /usr/bin/java ];then
	 zenity --error --title="Opsu!" --text="You need JAVA to run this game.
	 Go grab the JAVA PND, it's easy to install..."
	 exit
fi

if [ -z "$REAL_HOME" ];then
	export REAL_HOME="$HOME"
fi

export HOME=$pwd/home
export XDG_DATA_HOME=$pwd/home

if [ $lastrun -lt 3 ];then
	#extract specials skins...
	if [ ! -d Skins ];then
		mkdir Skins
	fi
	cd Skins
		(
			unzip ../skin_pandora_optimized.zip
		) |
		zenity --progress --pulsate --auto-close --text="Extracting custom Skins..." --title="Opsu!"
	cd ..
fi

if [ \( $lastrun -lt 6 \) -o \( ! -e Natives/ffmpeg32 \) ];then
	#extract Natives
	tar xf natives.tgz
fi

#all done, write the new lastrun...
if [ ! "$version" = "$lastrun" ];then
	echo "$version">home/.version
fi

MODEL=5
if [ -e /etc/powervr-esrev ];then
	MODEL=`cat /etc/powervr-esrev`
fi

export LIBGL_FB=1
#export LIBGL_BATCH=1
#export LIBGL_SHRINK=2
#export LIBGL_MIPMAP=3
#export LIBGL_ALPHAHACK=1
#export LIBGL_STREAM=1

if [ $MODEL -lt 5 ];then
	export LIBGL_SHRINK=7
fi

if [ -e .shrink ];then
	export LIBGL_SHRINK=`cat .shrink`
fi
if [ -e .mipmap ];then
	export LIBGL_MIPMAP=`cat .mipmap`
fi

if [ ! -e left_nub ];then
 cat /proc/pandora/nub0/mode >left_nub
fi
if [ ! -e right_nub ];then
 cat /proc/pandora/nub1/mode >right_nub
fi

left_nub=`cat left_nub`
right_nub=`cat right_nub`


free=`free -mt | grep Total | awk '{print $4}'`
echo System check
echo ============
echo Freememory is $free
echo Cpu Speed is `cat /proc/pandora/cpu_mhz_max`
echo Sys Speed is `cat /proc/pandora/sys_mhz_max`
echo Nubs as $left_nub, $right_nub
echo Pandora model = $MODEL
echo LIBGL_FB = $LIBGL_FB
echo LIBGL_BATCH = $LIBGL_BATCH
echo LIBGL_SHRINK = $LIBGL_SHRINK
echo DISPLAY = $DISPLAY

# handle analog nubs => save current version and switch to joystick for both
cat /proc/pandora/nub0/mode > /tmp/opsu_nub0mode_before
cat /proc/pandora/nub1/mode > /tmp/opsu_nub1mode_before
 
if [ -e /usr/pandora/scripts/op_nubchange.sh ]; then
  /usr/pandora/scripts/op_nubchange.sh $left_nub $right_nub
else
  echo $left_nub > /proc/pandora/nub0/mode
  echo $right_nub > /proc/pandora/nub1/mode
  sleep 1
fi

while : ; do
  rm .opsu_restart
  LD_PRELOAD=$pwd/lib/libxcb.so.1 java -Xmx160m -jar opsu-0.16.0.jar
  [ -e .opsu_restart ] || break
done

# set back the nubs to their initial state
cat /tmp/opsu_nub0mode_before > /proc/pandora/nub0/mode
cat /tmp/opsu_nub1mode_before > /proc/pandora/nub1/mode

sleep 1

rm /tmp/opsu_nub0mode_before /tmp/opsu_nub1mode_before
